@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Get XML.
 has xml => (
@@ -195,6 +195,28 @@ For more information about Dnipropetrovsk Map, click L<here|https://en.wikipedia
 
 =end html
 
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Dnipropetrovsk;
+
+ # Object.
+ my $obj = Map::Tube::Dnipropetrovsk->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Центрально-Заводська лінія
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -238,6 +260,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
